from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.naive_bayes import MultinomialNB
from sklearn.pipeline import make_pipeline
from sklearn.model_selection import train_test_split
from sklearn import metrics
import random

class YapayZekaPsikolog:
    def __init__(self):
        self.model = make_pipeline(TfidfVectorizer(), MultinomialNB())

    def eğit(self, veri):
        random.shuffle(veri)
        X = [item["hasta"] for item in veri]
        y = [item["rahatsizlik"] for item in veri]
        X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42)
        self.model.fit(X_train, y_train)
        tahminler = self.model.predict(X_test)
        doğruluk = metrics.accuracy_score(y_test, tahminler)
        print(f"Eğitim tamamlandı. Test doğruluğu: {doğruluk}")

    def terapiye_başla(self, hasta):
        tahmin = self.model.predict([hasta])
        return tahmin[0]

veri = [
    {"hasta": "Ben çok üzgün hissediyorum.", "rahatsizlik": "Depresyon"},
    {"hasta": "Sürekli endişeliyim ve kontrol kaybetme korkum var.", "rahatsizlik": "Anksiyete"},
    {"hasta": "Aklımdan sürekli kötü şeyler geçiyor.", "rahatsizlik": "Obsesif Kompulsif Bozukluk"},
    {"hasta": "Aniden nefes alamıyorum ve panik atak geçiriyorum.", "rahatsizlik": "Panik Atak"},
]

psikolog = YapayZekaPsikolog()
psikolog.eğit(veri)

ornek_hasta = "Sürekli bir hüzün içindeyim, ne yaparsam yapayım mutlu olamıyorum."
tahmin = psikolog.terapiye_başla(ornek_hasta)
print(f"Tahmin edilen rahatsızlık: {tahmin}")