from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.ensemble import RandomForestClassifier
from sklearn.pipeline import make_pipeline
from sklearn.model_selection import train_test_split
from sklearn import metrics
import joblib
import random

veri = [
    {"hasta": "Ben çok üzgün hissediyorum.", "rahatsizlik": "Depresyon"},
    {"hasta": "Sürekli endişeliyim ve kontrol kaybetme korkum var.", "rahatsizlik": "Anksiyete"},
    {"hasta": "Aklımdan sürekli kötü şeyler geçiyor.", "rahatsizlik": "Obsesif Kompulsif Bozukluk"},
    {"hasta": "Aniden nefes alamıyorum ve panik atak geçiriyorum.", "rahatsizlik": "Panik Atak"},
    {"hasta": "Bazı durumlarda ellerimi kontrol edemiyorum.", "rahatsizlik": "Tik Bozukluğu"},
    {"hasta": "Yemek yedikten sonra sık sık mide ağrısı çekiyorum.", "rahatsizlik": "Somatik Belirti Bozukluğu"},
]

random.shuffle(veri)
X = [item["hasta"] for item in veri]
y = [item["rahatsizlik"] for item in veri]
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42)
vectorizer = TfidfVectorizer()
X_train_tfidf = vectorizer.fit_transform(X_train)

for n_estimators in [50, 100, 200]:
    for max_depth in [None, 10, 20, 30]:
        model = RandomForestClassifier(n_estimators=n_estimators, max_depth=max_depth, random_state=42)
        model.fit(X_train_tfidf, y_train)
        X_test_tfidf = vectorizer.transform(X_test)
        y_pred = model.predict(X_test_tfidf)
        dogruluk = metrics.accuracy_score(y_test, y_pred)
        print(f"n_estimators={n_estimators}, max_depth={max_depth}, Test doğruluğu: {dogruluk}")

final_model = RandomForestClassifier(n_estimators=100, max_depth=None, random_state=42)
final_model.fit(X_train_tfidf, y_train)
def save_model(model, filename):
    joblib.dump(model, filename)
    print(f"Model '{filename}' başarıyla kaydedildi.")

save_model(final_model, 'AIpsikolog.joblib')

ornek_hasta = "Sürekli bir hüzün içindeyim, ne yaparsam yapayım mutlu olamıyorum."
tahmin = final_model.predict(vectorizer.transform([ornek_hasta]))
print(f"Tahmin edilen rahatsızlık: {tahmin[0]}")
